vim9script

# METAFONT indent file
# Language:           METAFONT
# Maintainer:         Nicola Vitacolonna <nvitacolonna@gmail.com>
# Latest Revision:    2026 Jan 10

runtime! indent/mp.vim

# vim: sw=2 fdm=marker
