" Vim keymap file for Azerbaijani language
" Maintainer: Rasul Samadzade <rasul.samadzade@protonmail.com>
" Last changed: 2025-06-13

let b:keymap_name = "az"

loadkeymap
w   ü
W   Ü
[   ö
{   Ö
]   ğ
}   Ğ
;   ı
:   I
'   ə
\"  Ə
,   ç
<   Ç
.   ş
>   Ş
\/  .
?   ,
@   "
#   Ⅶ
$   ;
^   :
&   ?
